# Generated by Django 3.2.5 on 2022-11-18 12:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0012_alter_ipn_account_number'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ipndata',
            name='ipn',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bank_sync.ipn'),
        ),
    ]
