# Generated by Django 3.2.5 on 2022-11-17 11:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0009_responselogs_error'),
    ]

    operations = [
        migrations.CreateModel(
            name='IPN',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('client_id', models.CharField(max_length=200, unique=True)),
                ('client_secret', models.CharField(max_length=200, unique=True)),
                ('bank_id', models.IntegerField()),
                ('account_number', models.CharField(max_length=200)),
                ('url', models.URLField()),
                ('status', models.BooleanField(choices=[(True, 'Active'), (False, 'Inactive')], default=True)),
                ('ipn_type', models.IntegerField(choices=[(2, 'Debit'), (1, 'Credit'), (0, 'Both')], default=0)),
            ],
        ),
        migrations.AlterModelOptions(
            name='callbacks',
            options={'verbose_name': 'Callback', 'verbose_name_plural': 'Callbacks'},
        ),
        migrations.AlterModelOptions(
            name='requestlogs',
            options={'verbose_name': 'Request Log', 'verbose_name_plural': 'Request Logs'},
        ),
        migrations.AlterModelOptions(
            name='responselogs',
            options={'verbose_name': 'Response Log', 'verbose_name_plural': 'Response Logs'},
        ),
    ]
